@@ -4,7 +4,7 @@
 #
 # Duplicity is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 2 of the License, or (at your
+# Free Software Foundation; either version 3 of the License, or (at your
 # option) any later version.
 #
 # Duplicity is distributed in the hope that it will be useful, but
@@ -367,4 +367,5 @@ class ITRBranch:
 		log.Log("Skipping %s because of previous error" % index_str, 2)
 
 
-import robust, log
+import duplicity.log as log
+import duplicity.robust as robust
